<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Kapat (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Daralt</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Genişlet</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Uyarıyı Kapat</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln kelime</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln dakika</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%Ln dakikanın %L1% &apos;i</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%Ln dakikanın %L1%&apos;si</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Günlük İlerleme</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>En uzun seri</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Şu anki seri</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n gün</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>Günlük hedeften % %L1</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Dili Ayarla</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Başlıksız %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Salt Okunur)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; kaydedilemedi.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Dosyayı Farklı Kaydet</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; üzerine yazılamadı.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Dosyayı Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; yeniden adlandırılamadı.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Dosya Yeniden Yüklensin mi?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>&apos;%1&apos; dosyası diskten yeniden yüklensin mi?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Tüm kaydedilmemiş değişiklikler kaybedilecektir.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Yeniden Yükle</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Başlıksız %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Düz metin olarak kaydetmek tüm biçimlendirleri geçersiz kılacaktır. Biçimlendirmeler geçersiz kılınsın mı?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Dosya Değişti</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>&apos;%1&apos; dosyası başka bir program tarafından değiştirilmiş.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Dosyayı yeniden yüklemek ister misiniz?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Yeniden Yükle</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Dosya Silindi</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>%1 dosyası başka bir program tarafından silindi.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Dosyayı kaydetmek mi kapatmak mı istiyorsunuz?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arşiv açılamadı.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Ara:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Şununla değiştir:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Büyük/küçük harf yoksay</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Yalnızca tam sözcükler</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Kurallı ifadeler</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Yukarıya doğru ara</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Aşağıya doğru ara</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Bul</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Değiştir</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>&amp;Tümünü Değiştir</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Bul</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Değiştir</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>%n öğe değiştirilsin mi?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>İfade bulunamadı.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Metni</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Ofis Açık XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Zengin Metin Biçimi</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Salt Metin</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tüm Dosyalar</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Tüm Desteklenen Dosyalar</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Düz XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Yazım Denetimi Yap...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Öneri bulunamadı)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Resim Aç</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Resimler</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arşiv açılamadı.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>İstatistikler</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Araç Çubuğu</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Yazım Denetimi</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Sözlük Seçin</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arşiv açılamadı.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arşiv kullanılabilir bir sözlük içermiyor.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Bir ya da daha fazla kısayol çakışıyor. Devam etmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; sözlüğü zaten var. Değiştirmek ister misiniz?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Günlük Hedef</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Dakika:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Kelime:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Düzenleme</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Her zaman dikey ortala</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Ekleme imlecini engelle</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Düzgün yazı tipleri</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Daktilo sesleri</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Akıllı tırnaklar:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Çift</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Tek</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Sahneler</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Bölen:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Kaydetme</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>İmleç konumu hatırla</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Kelime sayısı</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Sayfa sayısı</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Paragraf sayısı</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Karakter sayısı</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Karakter:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragraf:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Sözcük Sayım Algoritması</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Bugünkü ilerleme sıfırlansın mı?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Düz metin dosyalarında bayt sırası işareti yaz</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Varsayılan biçim:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Bugünü Sıfırla</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geçmiş</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Geçmişi hatırla</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Serileri göster</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Çizgiler için asgari ilerleme:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Sözcük sınırları algıla</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Karakter sayısını altıya böl</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Her harfi bir kelime olarak say</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Sayfa Sayma Algoritması</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Yalnızca Simgeler</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Yalnızca Metin</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Simge Yanında Metin</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Simge Altında Metin</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Metin Pozisyonu:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Eylemler</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Yukarı Taşı</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Aşağı Taşı</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Ayraç Ekle</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Eylem</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Yazarken yazım denetimi yap</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>BÜYÜK HARFLİ sözcükleri yoksay</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Sayı içeren sözcükleri yoksay</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Kişisel Sözlük</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Mevcut sözlük kaldırılsın mı?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Kullanıcı Arayüzü</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Her zaman kaydırma çubuğunu göster</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Her zaman üst çubuğu göster</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Her zaman alt çubuğu göster</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Desteklenmeyen bir RTF dosyası.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Dosya sonuna beklenmedik bir biçimde erişildi.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Aşağı Ok</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Sahneleri Yukarı Taşı</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Yukarı Ok</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Sahneler Arasında Geçiş Yap</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Sahne listesini göster (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Sahne listesini gizle (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrele</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Sahneleri Aşağı Taşı</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Sahne listesini yeniden boyutlandır</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Oturumları Yönet</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>&amp;Oturumlar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Çoğalt</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Geçiş Yap</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Yeni Oturum</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Oturumu Çoğalt</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Oturumu Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Seçili oturum silinsin mi?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Oturum adı:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>İstenen oturum adı zaten kullanımda.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Yeni...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Y&amp;önet...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Varsayılana Sıfırla</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Kısayol:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Tırnak işaretleri değiştiriliyor...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Lütfen Bekleyin</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Yazım Denetimi Yap</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Ekle</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Yoksay</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>&amp;Tümünü Gizle</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Değiştir</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>&amp;Tümünü Değiştir</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Sözlükte yok:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Değiştir:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Yazım denetimi yapılılıyor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal Et</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Lütfen bekleyin</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Kontrol etmeye dosya başından devam edilsin mi?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Yazım denetimi tamamlandı.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simgeler</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Son kullanılan simgeler</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Tüm simgeler</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Ekle</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloklar</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Betikler</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Başlıksız %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Resim Yok</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Döşe</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Ortala</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Uzat</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Ölçekle</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Saydamlık:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozisyon:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Genişlik:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Yuvarlak Metin Arka Plan Köşeleri</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Çap:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Metinlerin Arkaplanını Bulanıklaştırma</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Metin Arka Planı Alt Gölge</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Dikey Dengeleme:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Kenarlıklar</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Pencere:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Sayfa:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>İlk satır girintisi</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Altında:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Üstünde:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Temayı Düzenle</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Pencere Arka Planı</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Renk:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Resim:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> piksel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Metin Arka Planı</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Yazı Tipi:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>İmla Hataları:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Satır Aralığı</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Tek</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Satır</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Çift</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Orantısal</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Yükseklik:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Paragraf Boşluğu</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Sekme Genişliği:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Yeni Tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temalar</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Kibar Mavi</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Eski Okul</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Uzay Düşleri</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Yazı Masası</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Çoğalt</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Kişisel</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>&apos;%1&apos; teması silinsin mi?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temalar (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Temayı Al</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Temayı Ver</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>İliklere İşleyen Gökler </translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Büyü</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Ajan Oyunları</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Sükunet</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Zamanlayıcı silinsin mi?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Kelime:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Sayfa:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragraf:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Karakter:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Süre Ayarla</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Saat Ayarla</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Saat:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Not:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Çalışan zamanlayıcı yok</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Zamanlayıcılar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Zamanlayıcı düzenleme iptal edilsin mi?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Temalar yükleniyor</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Sesler yükleniyor</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Dosyayı Aç</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>FocusWriter Hakkında</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Basit bir tam ekran kelime işlemci</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Telif hakları saklıdır &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>&lt;a href=%1&gt;Oxygen&lt;/a&gt; simge temasından simgeler kullanılıyor</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında kullanılıyor</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Karakter: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Sayfa: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragraf: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Kelime: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 açılıyor</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Başlıksız %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Tüm dokümanları listele</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Sonraki Belgeye Geç</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Önceki Belgeye Geç</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>İlk Belgeye Geç</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Son Belgeye Geç</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>%1. Belgeye Geç</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Ayarlar yükleniyor</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Acil önbellek yazılabilir değil.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter temiz bir şekilde kapatılmadı.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Acil önbellekten kurtarılsın mı?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Bazı dosyalar açılamadı.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Bazı dosyalar salt okunur olarak açıldı.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; önbelleğe alınmış kopyadan daha yeni.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Daha yeni dosyanın üzerine yazılsın mı?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Değişiklikler Kaydedilsin mi?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Değişiklikler kapatılmadan önce &apos;%1&apos; dosyasına kaydedilsin mi?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Kaydetmezsen değişiklikler kaybedilecek.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Daktilo sesleri yüklenemiyor.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Aç...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>&amp;Yeniden Yükle</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>&amp;Farklı Kaydet...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Yeni &amp;İsim Ver...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>&amp;Tümünü Kaydet</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Oturumları Yönet</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Yeni Oturum</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Ya&amp;zdır...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Ka&amp;pat</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>D&amp;üzen</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Geri Al</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Yinele</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Kes</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opyala</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Y&amp;apıştır</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>&amp;Biçimlendirme Olmadan Yapıştır</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Tümünü Seç</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>&amp;Sahneyi Seç</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Biçim</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Kalın</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;İtalik</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Altı Çizili</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Üstü Çizili</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Ü&amp;st Simge</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>A&amp;lt Simge</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>So&amp;la Yasla</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Ortala</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Sa&amp;ğa  Yasla</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>İki &amp;Yana Yasla</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Girintiyi Azalt</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Gi&amp;rintiyi Arttır</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>S&amp;oldan Sağa Blok</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Sa&amp;ğdan Sola Blok</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Araçlar</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Bul...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>&amp;Sonrakini Bul</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Öncekini Bul</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Değiştir...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Akıllı Tırnaklar</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Dökümanı Güncelle</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>&amp;Seçilimi Güncelle</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Yazım Denetimi...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Dili &amp;Ayarla...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Zamanlayıcılar...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>&amp;Simgeler...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Günlük İlerleme</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Araç Çubuğunu Göster</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Menü Simgelerini Göster</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>&amp;Odaklanılan Metin</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Tam &amp;Ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>&amp;Küçült</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temalar...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Odaklanmayı Kapat</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Bir Satıra Odaklan</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Üç Satıra Odaklan</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Paragrafa Odaklan</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Uygulama Dili ...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Bazı dosyalar desteklenmiyor ve açılamadı.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Kapalı</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Bir Satır</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Üç Satır</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Say&amp;fa Ayarı...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Başlık &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Başlık &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Başlık &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Başlık &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Başlık &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Başlık &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Belge Akıllı Alıntılarını Güncelle</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Akıllı Alıntılar Seçimini Güncelle </translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Geçerli oturumda açılacak dosyalar.</translation>
    </message>
</context>
</TS>
